==> llamaapi-0.1.11-py3-none-any.whl: llamaapi/llamaapi.py <==
import aiohttp
import asyncio
import requests
import nest_asyncio

hostname = 'https://llama-api3.fly.dev'

class LlamaAPI:
    def __init__(self, api_token):
        self.hostname = hostname
        self.api_token = api_token
        self.headers = {'Llama-API-Token': self.api_token}

        # Apply nest_asyncio to enable nested usage of asyncio's event loop
        nest_asyncio.apply()

        # Add an asyncio queue
        self.queue = asyncio.Queue()

    async def _run_stream_for_jupyter(self, api_request_json):
        async with aiohttp.ClientSession() as session:
            async with session.post(f"{self.hostname}/api/chat", headers=self.headers, json=api_request_json) as resp:
                async for chunk in resp.content.iter_any():
                    await self.queue.put(chunk.decode('utf-8'))

    async def get_sequences(self):
        while True:
            sequence = await self.queue.get()
            # Do something with the sequence
            # You can add a check here to break the loop when a certain condition is met
            print(sequence)

    def _run_stream_jupyter(self, api_request_json):
        loop = asyncio.get_event_loop()
        loop.run_until_complete(self._run_stream(api_request_json))
        loop.run_until_complete(self.get_sequences())

    async def _run_async(self, api_request_json):
        async with aiohttp.ClientSession() as session:
            async with session.post(f"{self.hostname}/api/chat", headers=self.headers, json=api_request_json) as resp:
                return await resp.text()
    
    def _run_stream(self, api_request_json):
        # For simpler non-Jupyter execution, we use Python's built-in asyncio.run
        return asyncio.run(self._run_async(api_request_json))

    def _run_sync(self, api_request_json):
        response = requests.post(f"{self.hostname}/api/chat", headers=self.headers, json=api_request_json)
        if response.status_code != 200:
            raise Exception(f"POST {response.status_code}")
        return response

    def run(self, api_request_json):
        if api_request_json.get('stream', False):
            return self._run_stream(api_request_json)
        else:
            return self._run_sync(api_request_json)
        
    def run_jupyter(self, api_request_json):
        if api_request_json.get('stream', False):
            return self._run_stream_jupyter(api_request_json)
        else:
            return self._run_sync(api_request_json)

==> llamaapi-0.1.13-py3-none-any.whl: llamaapi/llamaapi.py <==
import aiohttp
import asyncio
import requests
import nest_asyncio

hostname = 'https://llama-api3.fly.dev'

class LlamaAPI:
    def __init__(self, api_token):
        self.hostname = hostname
        self.api_token = api_token
        self.headers = {'Llama-API-Token': self.api_token}

        # Apply nest_asyncio to enable nested usage of asyncio's event loop
        nest_asyncio.apply()

        # Add an asyncio queue
        self.queue = asyncio.Queue()

    async def _run_stream(self, api_request_json):
        async with aiohttp.ClientSession() as session:
            async with session.post(f"{self.hostname}/api/chat", headers=self.headers, json=api_request_json) as resp:
                async for chunk in resp.content.iter_any():
                    await self.queue.put(chunk.decode('utf-8'))

    async def get_sequences(self):
        while True:
            sequence = await self.queue.get()
            # Do something with the sequence
            # You can add a check here to break the loop when a certain condition is met
            print(sequence)

    def run_stream(self, api_request_json):
        loop = asyncio.get_event_loop()
        loop.run_until_complete(self._run_stream(api_request_json))
        loop.run_until_complete(self.get_sequences())

    def run_sync(self, api_request_json):
        response = requests.post(f"{self.hostname}/api/chat", headers=self.headers, json=api_request_json)
        if response.status_code != 200:
            raise Exception(f"POST {response.status_code}")
        return response.json()  # assuming server responds with JSON

    def run(self, api_request_json):
        if api_request_json.get('stream', False):
            return self.run_stream(api_request_json)
        else:
            return self.run_sync(api_request_json)
